@@ -20,7 +20,7 @@ from pkg_resources import load_entry_point
 from pkg_resources import resource_filename
 from webob import Request, Response, exc
 
-transformers = [i.lower() for i in transformers()]
+transformers = transformers()
 
 class Decoupage(object):
 
@@ -51,7 +51,7 @@ class Decoupage(object):
             assert os.path.isdir(directory), "Decoupage template directory %s does not exist!" % directory
 
         # static file server
-        self.fileserver = FileApp # XXX still used?!?
+        self.fileserver = FileApp
 
         # pluggable formats
         s = 'decoupage.format.'
@@ -115,12 +115,12 @@ class Decoupage(object):
                     kwargs = {}
                     for i in conf:
                         if i.startswith('/'):
-                            name = i[1:].lower()
+                            name = i[1:]
                             if name in transformers:
                                 kwargs[name] = dict([j.split('=', 1) for j in conf[i].split(',') if '=' in j])
                     fileserver = FileTypeTransformer(*args, **kwargs)
                 else:
-                    fileserver = FileApp
+                    fileserver = self.fileserver
                     
                 fileserver = fileserver(path)
                 return fileserver(environ, start_response)
@@ -249,7 +249,7 @@ class Decoupage(object):
                               'type': link})
             
         for f in files:
-            f['description'] = conf.get(f['name'].lower(), None)
+            f['description'] = conf.get(f['name'], None)
 
         return files
 
